@@ -26,6 +26,7 @@
 
 #include "ephy-about-handler.h"
 #include "ephy-prefs.h"
+#include "ephy-reader-handler.h"
 #include "ephy-settings.h"
 #include "ephy-string.h"
 #include "ephy-view-source-handler.h"
@@ -117,7 +118,7 @@ ephy_embed_utils_address_has_web_scheme (const char *address)
   if (address == NULL)
     return FALSE;
 
-  colonpos = (int)((g_strstr_len (address, 12, ":")) - address);
+  colonpos = (int)((strstr (address, ":")) - address);
 
   if (colonpos < 0)
     return FALSE;
@@ -130,7 +131,10 @@ ephy_embed_utils_address_has_web_scheme (const char *address)
                      g_ascii_strncasecmp (address, "blob", colonpos) &&
                      g_ascii_strncasecmp (address, "about", colonpos) &&
                      g_ascii_strncasecmp (address, "ephy-about", colonpos) &&
+                     g_ascii_strncasecmp (address, "ephy-resource", colonpos) &&
                      g_ascii_strncasecmp (address, "ephy-source", colonpos) &&
+                     g_ascii_strncasecmp (address, "ephy-reader", colonpos) &&
+                     g_ascii_strncasecmp (address, "ephy-pdf", colonpos) &&
                      g_ascii_strncasecmp (address, "gopher", colonpos) &&
                      g_ascii_strncasecmp (address, "inspector", colonpos) &&
                      g_ascii_strncasecmp (address, "webkit", colonpos));
@@ -393,7 +397,7 @@ ephy_embed_utils_is_no_show_address (const char *address)
     if (!strcmp (address, do_not_show_address[i]))
       return TRUE;
 
-  if (strstr (address, EPHY_VIEW_SOURCE_SCHEME) == address)
+  if (g_str_has_prefix (address, EPHY_VIEW_SOURCE_SCHEME))
     return TRUE;
 
   return FALSE;
